@@ -25,10 +25,11 @@ def generate_test(interactive, config, riotbase):
 
     test_params = params[group]
     if "use_testrunner" in test_params and test_params["use_testrunner"] in (
+        True,
         "True",
         "y",
     ):
-        testrunner_dir = os.path.join(output_dir, "test")
+        testrunner_dir = os.path.join(output_dir, "tests")
         render_source(params, group, {"01-run.py": None}, testrunner_dir)
         os.chmod(os.path.join(testrunner_dir, "01-run.py"), 0o755)
 
